"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usingFetch = exports.usingAjax = exports.loadScript = void 0;
const cache = new Map();
function loadScript(path, options) {
    var _a;
    const enableCache = (_a = options === null || options === void 0 ? void 0 : options.enableCache) !== null && _a !== void 0 ? _a : true;
    return new Promise((resolve, reject) => {
        if (enableCache && cache.get(path)) {
            return resolve();
        }
        const script = document.createElement('script');
        script.src = path;
        script.async = true;
        script.onerror = reject;
        script.onload = () => {
            enableCache && cache.set(path, true);
            return resolve();
        };
        document.head.appendChild(script);
    });
}
exports.loadScript = loadScript;
function usingAjax(path, options) {
    var _a;
    const enableCache = (_a = options === null || options === void 0 ? void 0 : options.enableCache) !== null && _a !== void 0 ? _a : true;
    return new Promise((resolve, reject) => {
        if (enableCache && cache.get(path)) {
            return resolve();
        }
        const xhr = new XMLHttpRequest();
        xhr.onreadystatechange = function () {
            if (xhr.readyState === 4) {
                const script = document.createElement('script');
                script.innerText = xhr.responseText;
                script.onerror = reject;
                document.head.appendChild(script);
                setTimeout(() => {
                    enableCache && cache.set(path, true);
                    return resolve();
                }, 0);
            }
        };
        xhr.onerror = reject;
        xhr.open('GET', path);
        xhr.send();
    });
}
exports.usingAjax = usingAjax;
function usingFetch(path, options) {
    var _a;
    const enableCache = (_a = options === null || options === void 0 ? void 0 : options.enableCache) !== null && _a !== void 0 ? _a : true;
    return new Promise((resolve, reject) => {
        if (enableCache && cache.get(path)) {
            return resolve();
        }
        return fetch(path)
            .then(res => res.text())
            .then(scriptText => {
            const script = document.createElement('script');
            script.innerText = scriptText;
            script.onerror = reject;
            document.head.appendChild(script);
            setTimeout(() => {
                enableCache && cache.set(path, true);
                return resolve();
            }, 0);
        });
    });
}
exports.usingFetch = usingFetch;
//# sourceMappingURL=load-script.js.map